(v0.6.x)=
### 0.6.\* {small}`2019-*-*`

- better support for aligned mappings (obsm, varm, layers)
  `0.6.22` {pr}`155` {smaller}`I Virshup`
- convenience accessors {func}`~anndata.AnnData.obs_vector`, {func}`~anndata.AnnData.var_vector` for 1d arrays.
  `0.6.21` {pr}`144` {smaller}`I Virshup`
- compatibility with Scipy >=1.3 by removing `IndexMixin` dependency.
  `0.6.20` {pr}`151` {smaller}`P Angerer`
- bug fix for second-indexing into views.
  `0.6.19` {smaller}`P Angerer`
- bug fix for reading excel files.
  `0.6.19` {smaller}`A Wolf`
- changed default compression to `None` in {func}`~anndata.AnnData.write_h5ad` to speed up read and write, disk space use is usually less critical.
  `0.6.16` {smaller}`A Wolf`
- maintain dtype upon copy.
  `0.6.13` {smaller}`A Wolf`
- {attr}`~anndata.AnnData.layers` inspired by [.loom](https://loompy.org) files allows their information lossless reading via {func}`~anndata.io.read_loom`.
  `0.6.7`–`0.6.9` {pr}`46` & {pr}`48` {smaller}`S Rybakov`
- support for reading zarr files: {func}`~anndata.io.read_zarr`
  `0.6.7` {pr}`38` {smaller}`T White`
- initialization from pandas DataFrames
  `0.6.` {smaller}`A Wolf`
- iteration over chunks {func}`~anndata.AnnData.chunked_X` and {func}`~anndata.AnnData.chunk_X`
  `0.6.1` {pr}`20` {smaller}`S Rybakov`
